Crate dioxus_markdown

Crate dioxus_markdown 

Structs

ComponentCreationError
error raised by the user of the library, when creating a component. It is automatically converted from any type of error
CustomComponents
component store. It is called when therer is a <CustomComponent> inside the markdown source. It is basically a hashmap but more efficient for a small number of items
ElementAttributes
LinkDescription
the description of a link, used to render it with a custom callback. See pulldown_cmark::Tag::Link for documentation
MarkdownMouseEvent
MdContext
MdProps
Options
Option struct containing flags for enabling extra features that are not part of the CommonMark spec.

Enums

HtmlElement

Traits

Context

Functions

Markdown

Type Aliases

HtmlCallback
MdComponentProps