pub struct CustomComponents(/* private fields */);Expand description
component store.
It is called when therer is a <CustomComponent> inside the markdown source.
It is basically a hashmap but more efficient for a small number of items
Implementations
Sourceimpl CustomComponents
impl CustomComponents
pub fn new() -> Self
Sourcepub fn register<F>(&mut self, name: &'static str, component: F)
pub fn register<F>(&mut self, name: &'static str, component: F)
register a new component.
The function component takes a context and props of type MdComponentProps
and returns html
pub fn get_callback( &self, name: &str, ) -> Option<&Callback<MdComponentProps, Result<Element, ComponentCreationError>>>