pub struct MarkdownMouseEvent {
pub mouse_event: MouseEvent,
pub position: Range<usize>,
}Fields
mouse_event: MouseEventthe original mouse event triggered when a text element was clicked on
position: Range<usize>the corresponding range in the markdown source, as a slice of u8