pub struct MdContext(/* private fields */);Trait Implementations
Sourceimpl<'src> Context<'src, 'static> for MdContext
impl<'src> Context<'src, 'static> for MdContext
type View = Result<VNode, RenderError>
type Handler<T: 'static> = Callback<T>
type MouseEvent = Event<MouseData>
Sourcefn el_with_attributes(
self,
e: HtmlElement,
inside: Self::View,
attributes: ElementAttributes<EventHandler<MouseEvent>>,
) -> Self::View
fn el_with_attributes( self, e: HtmlElement, inside: Self::View, attributes: ElementAttributes<EventHandler<MouseEvent>>, ) -> Self::View
creates a html element
attributes contains the html attributes for this elementSourcefn el_span_with_inner_html(
self,
inner_html: String,
attributes: ElementAttributes<EventHandler<MouseEvent>>,
) -> Self::View
fn el_span_with_inner_html( self, inner_html: String, attributes: ElementAttributes<EventHandler<MouseEvent>>, ) -> Self::View
renders raw html, inside a span
Sourcefn el_hr(
self,
attributes: ElementAttributes<EventHandler<MouseEvent>>,
) -> Self::View
fn el_hr( self, attributes: ElementAttributes<EventHandler<MouseEvent>>, ) -> Self::View
renders a
hr element, with attributesSourcefn el_fragment(self, children: Vec<Self::View>) -> Self::View
fn el_fragment(self, children: Vec<Self::View>) -> Self::View
takes a vector of views and return a view
Sourcefn mount_dynamic_link(
self,
_rel: &str,
_href: &str,
_integrity: &str,
_crossorigin: &str,
)
fn mount_dynamic_link( self, _rel: &str, _href: &str, _integrity: &str, _crossorigin: &str, )
add a styleshit to the markdown component
fn el_input_checkbox( self, checked: bool, attributes: ElementAttributes<EventHandler<MouseEvent>>, ) -> Self::View
Sourcefn props(self) -> MarkdownProps
fn props(self) -> MarkdownProps
get all the properties from the context
Sourcefn call_handler<T: 'static>(callback: &Self::Handler<T>, input: T)
fn call_handler<T: 'static>(callback: &Self::Handler<T>, input: T)
calls a callback with the given input
Sourcefn make_md_handler(
self,
position: Range<usize>,
stop_propagation: bool,
) -> Self::Handler<MouseEvent>
fn make_md_handler( self, position: Range<usize>, stop_propagation: bool, ) -> Self::Handler<MouseEvent>
creates a callback that will fire when the user clicks on markdown
Sourcefn set_frontmatter(&mut self, frontmatter: String)
fn set_frontmatter(&mut self, frontmatter: String)
write the frontmatter (or metadata) string
present at the top of the markdown source
fn has_custom_links(self) -> bool
fn render_links( self, link: LinkDescription<Self::View>, ) -> Result<Self::View, String>
fn has_custom_component(self, name: &str) -> bool
fn render_custom_component( self, name: &str, input: MdComponentProps, ) -> Result<Self::View, ComponentCreationError>
Sourcefn el(self, e: HtmlElement, inside: Self::View) -> Self::View
fn el(self, e: HtmlElement, inside: Self::View) -> Self::View
creates a html element, with default attributes
fn render_tasklist_marker(self, m: bool, position: Range<usize>) -> Self::View
fn render_rule(self, range: Range<usize>) -> Self::View
fn render_code(self, s: CowStr<'a>, range: Range<usize>) -> Self::View
fn render_text(self, s: CowStr<'a>, range: Range<usize>) -> Self::View
fn render_link( self, link: LinkDescription<Self::View>, ) -> Result<Self::View, String>
impl Copy for MdContext