pub struct LinkDescription<V> {
pub url: String,
pub content: V,
pub title: String,
pub link_type: LinkType,
pub image: bool,
}Expand description
the description of a link, used to render it with a custom callback. See pulldown_cmark::Tag::Link for documentation
Fields
url: Stringthe url of the link
content: Vthe html view of the element under the link
title: Stringthe title of the link. If you don’t know what it is, don’t worry: it is ofter empty
link_type: LinkTypethe type of link
image: boolwether the link is an image